==> apache-plc4x-0.11.0-source-release.zip: apache-plc4x-0.11.0/plc4go/spi/model/DefaultPlcUnsubscriptionRequestResult.go <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package model

import apiModel "github.com/apache/plc4x/plc4go/pkg/api/model"

var _ apiModel.PlcUnsubscriptionRequestResult = &DefaultPlcUnsubscriptionRequestResult{}

//go:generate go run ../../tools/plc4xgenerator/gen.go -type=DefaultPlcUnsubscriptionRequestResult
type DefaultPlcUnsubscriptionRequestResult struct {
	Request  apiModel.PlcUnsubscriptionRequest
	Response apiModel.PlcUnsubscriptionResponse
	Err      error
}

func NewDefaultPlcUnsubscriptionRequestResult(
	Request apiModel.PlcUnsubscriptionRequest,
	Response apiModel.PlcUnsubscriptionResponse,
	Err error,
) apiModel.PlcUnsubscriptionRequestResult {
	return &DefaultPlcUnsubscriptionRequestResult{Request, Response, Err}
}

func (d *DefaultPlcUnsubscriptionRequestResult) GetRequest() apiModel.PlcUnsubscriptionRequest {
	return d.Request
}

func (d *DefaultPlcUnsubscriptionRequestResult) GetResponse() apiModel.PlcUnsubscriptionResponse {
	return d.Response
}

func (d *DefaultPlcUnsubscriptionRequestResult) GetErr() error {
	return d.Err
}

==> apache-plc4x-0.13.1-source-release.zip: apache-plc4x-0.13.1/plc4go/spi/model/DefaultPlcUnsubscriptionRequestResult.go <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package model

import apiModel "github.com/apache/plc4x/plc4go/pkg/api/model"

var _ apiModel.PlcUnsubscriptionRequestResult = &DefaultPlcUnsubscriptionRequestResult{}

//go:generate go tool plc4xGenerator -type=DefaultPlcUnsubscriptionRequestResult
type DefaultPlcUnsubscriptionRequestResult struct {
	Request  apiModel.PlcUnsubscriptionRequest
	Response apiModel.PlcUnsubscriptionResponse
	Err      error
}

func NewDefaultPlcUnsubscriptionRequestResult(
	Request apiModel.PlcUnsubscriptionRequest,
	Response apiModel.PlcUnsubscriptionResponse,
	Err error,
) apiModel.PlcUnsubscriptionRequestResult {
	return &DefaultPlcUnsubscriptionRequestResult{Request, Response, Err}
}

func (d *DefaultPlcUnsubscriptionRequestResult) GetRequest() apiModel.PlcUnsubscriptionRequest {
	return d.Request
}

func (d *DefaultPlcUnsubscriptionRequestResult) GetResponse() apiModel.PlcUnsubscriptionResponse {
	return d.Response
}

func (d *DefaultPlcUnsubscriptionRequestResult) GetErr() error {
	return d.Err
}
